<?php

namespace EventPortal\Tests\Feature\Admin\Venue;

use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class VenueStoreTest extends TestCase
{
    use DatabaseMigrations, SeedRolesAndPermissions;

    /** @test */
    public function a_venue_can_be_created(): void
    {
        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.venue.store'), [
                'name' => 'A Venue',
                'website' => 'http://thicc.so',
                'line_1' => 'Line one',
                'city' => 'London',
                'country' => 'England',
                'area_code' => '1234',
            ])
            ->assertOk();

        $this->assertDatabaseHas('venues', [
            'name' => 'A Venue',
            'website' => 'http://thicc.so',
        ]);
        $this->assertDatabaseHas('addresses', [
            'line_1' => 'Line one',
            'country' => 'England',
            'area_code' => '1234',
        ]);
    }

    /** @test **/
    public function the_venue_name_is_required(): void
    {

        $this
            ->actingAsSuperAdmin()
            ->post(route('admin.venue.store'), [
                'name' => null,
                'website' => 'http://url.com',
            ])
            ->assertSessionHasErrors([
                'name',
            ]);

        $this->assertDatabaseMissing('venues', [
            'website' => 'http://url.com',
        ]);
    }
}
