<?php

namespace EventPortal\Tests\Unit\Email\Models;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Enums\EmailType;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EmailTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function default_attributes_are_stored_if_none_are_provided()
    {
        $event = factory(Event::class)->create();

        $email = EventEmail::create([
            'event_id' => $event->id,
            'type' => EmailType::invite(),
            'subject' => null,
            'sender_address' => null,
            'reply_to_address' => null,
        ]);

        $this->assertEquals('Your invitation', $email->subject);
        $this->assertEquals('event-portal@example.com', $email->sender_address);
        $this->assertEquals('event-portal@example.com', $email->reply_to_address);

        $this->markTestIncomplete('Need to use event name in subject?');
    }

    /** @test **/
    public function the_subject_uses_the_event_name()
    {
        $this->markTestIncomplete('Not yet implemented');
    }

    /** @test **/
    public function an_email_has_a_type()
    {
        factory(EventEmail::class)->state('invite')->create();
        factory(EventEmail::class, 2)->state('save-the-date')->create();

        $this->assertEquals(1, EventEmail::whereEnum('type', EmailType::invite())->count());
        $this->assertEquals(2, EventEmail::whereEnum('type', EmailType::saveTheDate())->count());
    }

    /** @test **/
    public function the_type_can_be_displayed_as_text()
    {
        $inviteEmail = factory(EventEmail::class)->state('invite')->create();
        $saveTheDateEmail = factory(EventEmail::class)->state('save-the-date')->create();

        $this->assertEquals('Invite', $inviteEmail->type);
        $this->assertEquals('Save the date', $saveTheDateEmail->type);
    }

    /** @test **/
    public function an_email_can_be_associated_with_an_event()
    {
        $event = factory(Event::class)->create();
        $email = factory(EventEmail::class)->create([
            'event_id' => $event->id,
        ]);
        $differentEvent = factory(Event::class)->create();

        $this->assertTrue($email->event->is($event));
        $this->assertFalse($email->event->is($differentEvent));
    }

    /** @test **/
    public function the_email_view_and_notification_key_can_be_generated()
    {
        $inviteEmail = factory(EventEmail::class)->state('invite')->create();
        $saveTheDateEmail = factory(EventEmail::class)->state('save-the-date')->create();
        $joiningInstructionsEmail = factory(EventEmail::class)->state('joining-instructions')->create();
        $postEmail = factory(EventEmail::class)->state('post')->create();

        $this->assertEquals('event.invite', $inviteEmail->getNotificationKey());
        $this->assertEquals('event.save-the-date', $saveTheDateEmail->getNotificationKey());
        $this->assertEquals('event.joining-instructions', $joiningInstructionsEmail->getNotificationKey());
        $this->assertEquals('event.post-event', $postEmail->getNotificationKey());
    }
}
